==> skill-admin-home-18.0.3-sources.jar: com/ptteng/interceptor/UserInterceptor.java <==
package com.ptteng.interceptor;

import com.gemantic.commons.code.annotation.FileTemplate;
import com.gemantic.commons.code.util.GenerateFileUtil;
import com.ptteng.common.skill.model.Manager;
import com.ptteng.common.skill.model.Module;
import com.ptteng.common.skill.model.RoleModule;
import com.ptteng.common.skill.service.ManagerService;
import com.ptteng.common.skill.service.ModuleService;
import com.ptteng.common.skill.service.RoleModuleService;
import com.ptteng.common.skill.service.RoleService;
import com.qding.common.util.http.cookie.CookieUtil;
import com.qding.common.util.http.cookie.UserCryptUtil;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.lang.reflect.Method;
import java.net.URLEncoder;
import java.util.*;

public class UserInterceptor extends HandlerInterceptorAdapter {

    private static final Log log = LogFactory.getLog(UserInterceptor.class);

    @Autowired
    private ManagerService managerService;
    @Autowired
    private RoleService roleService;

    @Autowired
    private ModuleService moduleService;

    @Autowired
    private RoleModuleService roleModuleService;
    public static String SPLITTER_REGEX = "\\|";
    public static final String USER_ID = "userId";

    @Autowired
    private CookieUtil cookieUtil;

    @Autowired
    @Qualifier("velocityGenerateFileUtil")
    private GenerateFileUtil generate;

    /**
     * In this case intercept the request BEFORE it reaches the controller
     */
//	@Override
//	public boolean preHandle(HttpServletRequest request,
//			HttpServletResponse response, Object handler) throws Exception {
//
//
//		Cookie[] cookies = request.getCookies();
//		log.info("get cookies  " + Arrays.asList(cookies));
//		Map<String, String> maps = cookieUtil.getIdentity(request);
//		log.info("get maps  from cookie is " + maps);
//		Long uid = cookieUtil.getID(request, response);
//		if (uid == null) {
//
//			log.error("not legal user request");
//			return wrongUser(response);
//
//		}
//		log.info("get uid  from cookie is " + uid);
//		User user = this.userService.getObjectById(uid);
//		if (user == null) {
//			log.error(uid + " not get any data ");
//			return wrongUser(response);
//		}else{
//			log.info("get usr "+user);
//			request.setAttribute("user", user);
//		}
//		log.info("get uid is " + uid);
//
//		return true;
//	}

    @Override
    public boolean preHandle(HttpServletRequest request,
                             HttpServletResponse response, Object handler) throws Exception {
        log.info("intercepter preHandle start ...");

        String token = request.getParameter("token");
        if(null == token){
            token = request.getHeader("token");
        }
        log.info(" intercept token is    "+token);
//
//
//
//        String uid_cookie = cookieUtil.getKeyIdentity(request,
//                CookieUtil.USER_ID);
//
//        if (org.apache.commons.lang3.StringUtils.isBlank(uid_cookie)) {
//            log.info(" intercept uid is    "+uid_cookie);
//            response.sendRedirect("/index");
//            return false;
//        }
//
//
        //       Map map = decodeCookie(token);
        //      Long uid = null;
        //       Manager user = null;
        //      if(null!=map){
        //         uid=  (Long) map.get(USER_ID);
//       }
//
//        if(null != uid){
//            user = this.userService.getObjectById(uid);
//            request.setAttribute("user", user);
//            log.info(" intercept user is    " + user);
//        }
        Cookie[] cookies = request.getCookies();
        log.info("get cookies  " + Arrays.asList(cookies));
        Map<String, String> maps = cookieUtil.getIdentity(request);
        log.info("get maps  from cookie is " + maps);
        Long   uid =  cookieUtil.getID(request);


        log.info(uid);
        if (uid == null) {

            log.error("not legal user request");
            return noLogin(response);

        }
        log.info("get uid  from cookie is " + uid);
        Manager manager = this.managerService.getObjectById(uid);
        if (manager == null) {
            log.error(uid + " not get any data ");
            return noLogin(response);
        }else{
            log.info("get manager name " + manager.getName());
            request.setAttribute("manager", manager);
        }
        log.info("get uid is " + uid);


        String requestUrl =        this.getInterceptorUrl(request);
        log.info(" requstUrl  " + requestUrl);

        List<Long> roleModuleIds =  roleModuleService.getRoleModuleIdsByRid(manager.getRoleID(), 0, Integer.MAX_VALUE);
        List<RoleModule> roleModules =    roleModuleService.getObjectsByIds(roleModuleIds);
        List<Long>  mids = new ArrayList<Long>();
        for(RoleModule roleModule : roleModules){
           mids.add(roleModule.getMid());
        }
        List<Module> modules = moduleService.getObjectsByIds(mids);
        boolean flag = false;
        String[] requestUrls =  requestUrl.split("\\?");
        log.info(" reqeust is "+requestUrls[0]);
        for(Module module : modules){
            log.info(" module url is  "+module.getUrl());

            log.info("the flag is " + flag);

            if (module.getUrl() != null){


                String[] moduleUrls = module.getUrl().split("\\.");
                log.info(" managerUrl  is  ==" + moduleUrls.length);
//            if(  requestUrls[0].contains(moduleUrls.length == 1 ?"0000" : moduleUrls[1])){
//                log.info(uid + " is have module " +moduleUrls[1]);
//                flag=true;
//               break;
//            }
                if (moduleUrls.length > 1) {
                    if (requestUrls[0].contains(moduleUrls[1]))
                        log.info(uid + " is have module " + moduleUrls[1]);
                    flag = true;
                    break;
                }

            }else {
                flag = true;
            }
            log.info("the flag is " + flag);

        }


       if(flag==false){
           log.info(uid +" is don't have module "+requestUrl);
           return  noPermission(response);
       }

        return  true;
    }

    public static Map getUserIdentity(String userName, Long userId) {
        Map map = new HashMap();
        map.put(CookieUtil.USER_NAME, userName);
        map.put(CookieUtil.USER_ID, userId);
        return map;
    }

    private  Map decodeCookie(String value) {
        if (StringUtils.isBlank(value))
            return null;
        try {
            String[] p = value.split(SPLITTER_REGEX);
            Long userId = new Long(p[0]);
            String crypt = p[1];
            String plainUserInfo = UserCryptUtil.userDecrypt(crypt);
            String userName = UserCryptUtil.getUserNameFromPlain(plainUserInfo);
            Long uid = UserCryptUtil.getUserIdFromPlain(plainUserInfo);
            if (userId.equals(uid)) {
                return getUserIdentity(userName, userId);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("Wrong cookie format: [" + value + "] message is:" + e.getMessage());
            return null;
        }

        return null;
    }

    private boolean noPermission(HttpServletResponse response) throws IOException {

        response.sendRedirect("/noPermissin");
        return false;

    }

    private boolean noLogin(HttpServletResponse response) throws IOException {

        response.sendRedirect("/nologin");
        return false;

    }

    @Override
    public void postHandle(HttpServletRequest request,
                           HttpServletResponse response, Object handler,
                           ModelAndView modelAndView) throws Exception {

        log.info("    postHandle  start ======================== ");

        if(request.getRequestURI().contains("/a/u/record/excel")) {

            HandlerMethod handlerMethod = (HandlerMethod) handler;

            Method method = handlerMethod.getMethod();
            log.info("method name is " + method.getName());

            Map model = modelAndView.getModel();

            String excelName = "record_" + System.currentTimeMillis() + ".csv";

            if (method.isAnnotationPresent(FileTemplate.class)) {
                FileTemplate fileTemplate = method.getAnnotation(FileTemplate.class);

                String content = generate.generateFileEncoding(model, fileTemplate.templatePath(), fileTemplate.filePath(),
                        excelName, false, "GBK");
                log.info("test result is " + content);
            }

            String url = "/exceldownload/" + excelName;
            log.info("export excel success, download url: " + url);
            model.put("url", url);
            model.put("code", 0);
            modelAndView.setViewName("/common/export");
        }
    }

    /**
     * 获取跳转链接的地址
     *
     * @param request
     * @return
     */
    public String getInterceptorUrl(HttpServletRequest request) {

        String interceptorUrl = request.getRequestURI()
                + (null == request.getQueryString() ? "" : "?"
                + request.getQueryString()).toString();
        interceptorUrl = interceptorUrl.replace("/app/", "/");

        log.info("get getInterceptorUrl is " + interceptorUrl);

        return interceptorUrl;
    }

    public static void main(String[] args) throws UnsupportedEncodingException {

        String x = URLEncoder.encode("p/hello", "utf-8");
        log.info(x);

    }
}

==> skill-admin-home-25.0.2-sources.jar: com/ptteng/interceptor/UserInterceptor.java <==
package com.ptteng.interceptor;

import com.gemantic.commons.code.annotation.FileTemplate;
import com.gemantic.commons.code.util.GenerateFileUtil;
import com.ptteng.common.skill.model.Manager;
import com.ptteng.common.skill.model.Module;
import com.ptteng.common.skill.model.RoleModule;
import com.ptteng.common.skill.service.ManagerService;
import com.ptteng.common.skill.service.ModuleService;
import com.ptteng.common.skill.service.RoleModuleService;
import com.ptteng.common.skill.service.RoleService;
import com.qding.common.util.http.cookie.CookieUtil;
import com.qding.common.util.http.cookie.UserCryptUtil;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.lang.reflect.Method;
import java.net.URLEncoder;
import java.util.*;

public class UserInterceptor extends HandlerInterceptorAdapter {

    private static final Log log = LogFactory.getLog(UserInterceptor.class);

    @Autowired
    private ManagerService managerService;
    @Autowired
    private RoleService roleService;

    @Autowired
    private ModuleService moduleService;

    @Autowired
    private RoleModuleService roleModuleService;
    public static String SPLITTER_REGEX = "\\|";
    public static final String USER_ID = "userId";

    @Autowired
    private CookieUtil cookieUtil;

    @Autowired
    @Qualifier("velocityGenerateFileUtil")
    private GenerateFileUtil generate;

    /**
     * In this case intercept the request BEFORE it reaches the controller
     */
//	@Override
//	public boolean preHandle(HttpServletRequest request,
//			HttpServletResponse response, Object handler) throws Exception {
//
//
//		Cookie[] cookies = request.getCookies();
//		log.info("get cookies  " + Arrays.asList(cookies));
//		Map<String, String> maps = cookieUtil.getIdentity(request);
//		log.info("get maps  from cookie is " + maps);
//		Long uid = cookieUtil.getID(request, response);
//		if (uid == null) {
//
//			log.error("not legal user request");
//			return wrongUser(response);
//
//		}
//		log.info("get uid  from cookie is " + uid);
//		User user = this.userService.getObjectById(uid);
//		if (user == null) {
//			log.error(uid + " not get any data ");
//			return wrongUser(response);
//		}else{
//			log.info("get usr "+user);
//			request.setAttribute("user", user);
//		}
//		log.info("get uid is " + uid);
//
//		return true;
//	}

    @Override
    public boolean preHandle(HttpServletRequest request,
                             HttpServletResponse response, Object handler) throws Exception {
        log.info("intercepter preHandle start ...");

        String token = request.getParameter("token");
        if(null == token){
            token = request.getHeader("token");
        }
        log.info(" intercept token is    "+token);
//
//
//
//        String uid_cookie = cookieUtil.getKeyIdentity(request,
//                CookieUtil.USER_ID);
//
//        if (org.apache.commons.lang3.StringUtils.isBlank(uid_cookie)) {
//            log.info(" intercept uid is    "+uid_cookie);
//            response.sendRedirect("/index");
//            return false;
//        }
//
//
        //       Map map = decodeCookie(token);
        //      Long uid = null;
        //       Manager user = null;
        //      if(null!=map){
        //         uid=  (Long) map.get(USER_ID);
//       }
//
//        if(null != uid){
//            user = this.userService.getObjectById(uid);
//            request.setAttribute("user", user);
//            log.info(" intercept user is    " + user);
//        }
        Cookie[] cookies = request.getCookies();
        log.info("get cookies  " + Arrays.asList(cookies));
        Map<String, String> maps = cookieUtil.getIdentity(request);
        log.info("get maps  from cookie is " + maps);
        Long   uid =  cookieUtil.getID(request);


        log.info(uid);
        if (uid == null) {

            log.error("not legal user request");
            return noLogin(response);

        }
        log.info("get uid  from cookie is " + uid);
        Manager manager = this.managerService.getObjectById(uid);
        if (manager == null) {
            log.error(uid + " not get any data ");
            return noLogin(response);
        }else{
            log.info("get manager name " + manager.getName());
            request.setAttribute("manager", manager);
        }
        log.info("get uid is " + uid);


        String requestUrl =        this.getInterceptorUrl(request);
        log.info(" requstUrl  " + requestUrl);

        List<Long> roleModuleIds =  roleModuleService.getRoleModuleIdsByRid(manager.getRoleID(), 0, Integer.MAX_VALUE);
        List<RoleModule> roleModules =    roleModuleService.getObjectsByIds(roleModuleIds);
        List<Long>  mids = new ArrayList<Long>();
        for(RoleModule roleModule : roleModules){
           mids.add(roleModule.getMid());
        }
        List<Module> modules = moduleService.getObjectsByIds(mids);
        boolean flag = false;
        String[] requestUrls =  requestUrl.split("\\?");
        log.info(" reqeust is "+requestUrls[0]);
        for(Module module : modules){
            log.info(" module url is  "+module.getUrl());

            log.info("the flag is " + flag);

            if (module.getUrl() != null){


                String[] moduleUrls = module.getUrl().split("\\.");
                log.info(" managerUrl  is  ==" + moduleUrls.length);
//            if(  requestUrls[0].contains(moduleUrls.length == 1 ?"0000" : moduleUrls[1])){
//                log.info(uid + " is have module " +moduleUrls[1]);
//                flag=true;
//               break;
//            }
                if (moduleUrls.length > 1) {
                    if (requestUrls[0].contains(moduleUrls[1])){
                        log.info(uid + " is have module " + moduleUrls[1]);
                        flag = true;
                        break;
                    }else{

                    }

                }

            }else {
                flag = true;
            }
            log.info("the flag is " + flag);

        }


       if(flag==false){
           log.info(uid +" is don't have module "+requestUrl);
           return  noPermission(response);
       }

        return  true;
    }

    public static Map getUserIdentity(String userName, Long userId) {
        Map map = new HashMap();
        map.put(CookieUtil.USER_NAME, userName);
        map.put(CookieUtil.USER_ID, userId);
        return map;
    }

    private  Map decodeCookie(String value) {
        if (StringUtils.isBlank(value))
            return null;
        try {
            String[] p = value.split(SPLITTER_REGEX);
            Long userId = new Long(p[0]);
            String crypt = p[1];
            String plainUserInfo = UserCryptUtil.userDecrypt(crypt);
            String userName = UserCryptUtil.getUserNameFromPlain(plainUserInfo);
            Long uid = UserCryptUtil.getUserIdFromPlain(plainUserInfo);
            if (userId.equals(uid)) {
                return getUserIdentity(userName, userId);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("Wrong cookie format: [" + value + "] message is:" + e.getMessage());
            return null;
        }

        return null;
    }

    private boolean noPermission(HttpServletResponse response) throws IOException {

        response.sendRedirect("/noPermissin");
        return false;

    }

    private boolean noLogin(HttpServletResponse response) throws IOException {

        response.sendRedirect("/nologin");
        return false;

    }

    @Override
    public void postHandle(HttpServletRequest request,
                           HttpServletResponse response, Object handler,
                           ModelAndView modelAndView) throws Exception {

        log.info("    postHandle  start ======================== ");

        if(request.getRequestURI().contains("/a/u/record/excel")) {

            HandlerMethod handlerMethod = (HandlerMethod) handler;

            Method method = handlerMethod.getMethod();
            log.info("method name is " + method.getName());

            Map model = modelAndView.getModel();

            String excelName = "record_" + System.currentTimeMillis() + ".csv";

            if (method.isAnnotationPresent(FileTemplate.class)) {
                FileTemplate fileTemplate = method.getAnnotation(FileTemplate.class);

                String content = generate.generateFileEncoding(model, fileTemplate.templatePath(), fileTemplate.filePath(),
                        excelName, false, "GBK");
                log.info("test result is " + content);
            }

            String url = "/exceldownload/" + excelName;
            log.info("export excel success, download url: " + url);
            model.put("url", url);
            model.put("code", 0);
            modelAndView.setViewName("/common/export");
        }
    }

    /**
     * 获取跳转链接的地址
     *
     * @param request
     * @return
     */
    public String getInterceptorUrl(HttpServletRequest request) {

        String interceptorUrl = request.getRequestURI()
                + (null == request.getQueryString() ? "" : "?"
                + request.getQueryString()).toString();
        interceptorUrl = interceptorUrl.replace("/app/", "/");

        log.info("get getInterceptorUrl is " + interceptorUrl);

        return interceptorUrl;
    }

    public static void main(String[] args) throws UnsupportedEncodingException {

        String x = URLEncoder.encode("p/hello", "utf-8");
        log.info(x);

    }
}
